@@ -8,7 +8,11 @@ import sh
 from django.conf import settings
 from django.core.management.base import NoArgsCommand, BaseCommand
 from django.utils.crypto import get_random_string
+from django.core.files.storage import default_storage
 
+from storages.backends.s3boto import S3BotoStorage
+
+from herokuapp.commands import HerokuCommandError
 from herokuapp.management.commands.base import HerokuCommandMixin
 
 
@@ -31,6 +35,12 @@ class Command(HerokuCommandMixin, NoArgsCommand):
         ),
     ) + HerokuCommandMixin.option_list
     
+    def exit_with_error(self, error):
+        self.stderr.write(error + "\n")
+        self.stderr.write("Heroku audit aborted.\n")
+        self.stderr.write("Run `./manage.py heroku_audit --fix` to fix problems.\n")
+        sys.exit(1)
+
     def prompt_for_fix(self, error, message):
         if self.fix:
             self.stdout.write(error + "\n")
@@ -49,9 +59,7 @@ class Command(HerokuCommandMixin, NoArgsCommand):
             answer_bool = False
         # Exit if no fix provided.
         if not answer_bool:
-            self.stderr.write(error + "\n")
-            self.stderr.write("Heroku audit aborted.\n")
-            sys.exit(1)
+            self.exit_with_error(error)
 
     def read_string(self, message, default):
         if self.interactive:
@@ -74,10 +82,14 @@ class Command(HerokuCommandMixin, NoArgsCommand):
         # Check app exists.
         try:
             self.heroku("apps:info")
-        except sh.ErrorReturnCode:
+        except HerokuCommandError:
             self.prompt_for_fix("No Heroku app named '{app}' detected.".format(app=self.app), "Create app?")
             self.heroku("apps:create", self.app)
             self.stdout.write("Heroku app created.")
+        # Check that Amazon S3 is being used for media.
+        default_storage._setup()
+        if not isinstance(default_storage._wrapped, S3BotoStorage):
+            self.exit_with_error("settings.DEFAULT_FILE_STORAGE should be set to a subclass of `storages.backends.s3boto.S3BotoStorage`.")
         # Check for AWS access details.
         if not self.heroku.config_get("AWS_ACCESS_KEY_ID"):
             self.prompt_for_fix("Amazon S3 access details not present in Heroku config.", "Setup now?")
@@ -89,7 +101,7 @@ class Command(HerokuCommandMixin, NoArgsCommand):
             self.heroku.config_set(**aws_env)
             self.stdout.write("Amazon S3 config written to Heroku config.")
         # Check for SendGrid settings.
-        if not self.heroku.config_get("SENDGRID_USERNAME"):
+        if settings.EMAIL_HOST == "smtp.sendgrid.net" and not self.heroku.config_get("SENDGRID_USERNAME"):
             self.prompt_for_fix("SendGrid addon not installed.", "Provision SendGrid starter addon (free)?")
             self.heroku("addons:add", "sendgrid:starter")
             self.stdout.write("SendGrid addon provisioned.")
@@ -108,15 +120,19 @@ class Command(HerokuCommandMixin, NoArgsCommand):
             self.heroku("pg:promote", database_url)
             self.stdout.write("Heroku primary database URL set.")
         # Check for secret key.
-        if not self.heroku.config_get("SECRET_KEY"):
+        heroku_secret_key = self.heroku.config_get("SECRET_KEY")
+        if not heroku_secret_key:
             self.prompt_for_fix("Secret key not set in Heroku config.", "Generate now?")
             self.heroku.config_set(SECRET_KEY=get_random_string(50, "abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)"))
-            self.stdout.write("Secret key written to Heroku config.")
+            self.stdout.write("Secret key written to Heroku config. Ensure your settings file is configured to read the secret key: https://github.com/etianen/django-herokuapp#improving-site-security")
         # Check for Python hash seed.
         if not self.heroku.config_get("PYTHONHASHSEED"):
             self.prompt_for_fix("Python hash seed not set in Heroku config.", "Set now?")
             self.heroku.config_set(PYTHONHASHSEED="random")
             self.stdout.write("Python hash seed written to Heroku config.")
+        # Check for SSL header settings.
+        if not getattr(settings, "SECURE_PROXY_SSL_HEADER", None) == ("HTTP_X_FORWARDED_PROTO", "https"):
+            self.exit_with_error("Missing SECURE_PROXY_SSL_HEADER settings. Please add `SECURE_PROXY_SSL_HEADER = (\"HTTP_X_FORWARDED_PROTO\", \"https\")` to your settings.py file.")
         # Check for Procfile.
         procfile_path = os.path.join(settings.BASE_DIR, "Procfile")
         if not os.path.exists(procfile_path):
