@@ -1,7 +1,13 @@
 #!/usr/bin/env python
-import os, sys
+import os
+import sys
 
 if __name__ == "__main__":
+    
+    # Load the Heroku environment.
+    from herokuapp.env import load_env
+    load_env(__file__, "{{ app_name }}")
+
     os.environ.setdefault("DJANGO_SETTINGS_MODULE", "{{ project_name }}.settings")
 
     from django.core.management import execute_from_command_line
